pub struct TradeClientExtensionsModifyTransaction {
pub id: Option<i32>,
pub time: Option<String>,
pub user_id: Option<i32>,
pub account_id: Option<String>,
pub batch_id: Option<i32>,
pub request_id: Option<String>,
pub type: Option<TransactionType>,
pub trade_id: Option<i32>,
pub client_trade_id: Option<String>,
pub trade_client_extensions_modify: Option<Box<ClientExtensions>>,
}Expand description
TradeClientExtensionsModifyTransaction : A TradeClientExtensionsModifyTransaction represents the modification of a Trade’s Client Extensions.
Fields
id: Option<i32>The Transaction’s Identifier.
time: Option<String>A date and time value using either RFC3339 or UNIX time representation. The RFC 3339 representation is a string conforming to https://tools.ietf.org/rfc/rfc3339.txt. The Unix representation is a string representing the number of seconds since the Unix Epoch (January 1st, 1970 at UTC). The value is a fractional number, where the fractional part represents a fraction of a second (up to nine decimal places).
user_id: Option<i32>The ID of the user that initiated the creation of the Transaction.
account_id: Option<String>The Account’s identifier
batch_id: Option<i32>The ID of the "batch" that the Transaction belongs to. Transactions in the same batch are applied to the Account simultaneously.
request_id: Option<String>The Request ID of the request which generated the transaction.
type: Option<TransactionType>trade_id: Option<i32>The ID of the Trade who’s client extensions are to be modified.
client_trade_id: Option<String>The original Client ID of the Trade who’s client extensions are to be modified.
trade_client_extensions_modify: Option<Box<ClientExtensions>>Implementations
Sourceimpl TradeClientExtensionsModifyTransaction
impl TradeClientExtensionsModifyTransaction
Sourcepub fn new() -> TradeClientExtensionsModifyTransaction
pub fn new() -> TradeClientExtensionsModifyTransaction
A TradeClientExtensionsModifyTransaction represents the modification of a Trade’s Client Extensions.